@@ -6,6 +6,7 @@ import { buildAbilityForUser } from '@tamanu/shared/permissions/buildAbility';
 
 import {
   AuthExpiredError,
+  ResourceConflictError,
   ServerResponseError,
   VersionIncompatibleError,
   getVersionIncompatibleMessage,
@@ -216,6 +217,11 @@ export class TamanuApi {
       }
     }
 
+    // Handle resource conflict
+    if (response.status === 409) {
+      throw new ResourceConflictError(message)
+    }
+
     throw new ServerResponseError(`Server error response: ${message}`);
   }
 
